# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ModelEndpoint(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'endpoint_arn': 'str',
        'status': 'str',
        'config': 'object',
        'model_id': 'str',
        'model_job_id': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'version': 'float'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'endpoint_arn': 'endpointArn',
        'status': 'status',
        'config': 'config',
        'model_id': 'modelId',
        'model_job_id': 'modelJobId',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'version': 'version'
    }

    def __init__(self, id=None, name=None, endpoint_arn=None, status=None, config=None, model_id=None, model_job_id=None, created_at=None, updated_at=None, version=None):  # noqa: E501
        """ModelEndpoint - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._endpoint_arn = None
        self._status = None
        self._config = None
        self._model_id = None
        self._model_job_id = None
        self._created_at = None
        self._updated_at = None
        self._version = None
        self.discriminator = None
        if id is not None:
            self.id = id
        self.name = name
        if endpoint_arn is not None:
            self.endpoint_arn = endpoint_arn
        if status is not None:
            self.status = status
        if config is not None:
            self.config = config
        self.model_id = model_id
        self.model_job_id = model_job_id
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if version is not None:
            self.version = version

    @property
    def id(self):
        """Gets the id of this ModelEndpoint.  # noqa: E501


        :return: The id of this ModelEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ModelEndpoint.


        :param id: The id of this ModelEndpoint.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ModelEndpoint.  # noqa: E501


        :return: The name of this ModelEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ModelEndpoint.


        :param name: The name of this ModelEndpoint.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def endpoint_arn(self):
        """Gets the endpoint_arn of this ModelEndpoint.  # noqa: E501


        :return: The endpoint_arn of this ModelEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_arn

    @endpoint_arn.setter
    def endpoint_arn(self, endpoint_arn):
        """Sets the endpoint_arn of this ModelEndpoint.


        :param endpoint_arn: The endpoint_arn of this ModelEndpoint.  # noqa: E501
        :type: str
        """

        self._endpoint_arn = endpoint_arn

    @property
    def status(self):
        """Gets the status of this ModelEndpoint.  # noqa: E501


        :return: The status of this ModelEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ModelEndpoint.


        :param status: The status of this ModelEndpoint.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def config(self):
        """Gets the config of this ModelEndpoint.  # noqa: E501


        :return: The config of this ModelEndpoint.  # noqa: E501
        :rtype: object
        """
        return self._config

    @config.setter
    def config(self, config):
        """Sets the config of this ModelEndpoint.


        :param config: The config of this ModelEndpoint.  # noqa: E501
        :type: object
        """

        self._config = config

    @property
    def model_id(self):
        """Gets the model_id of this ModelEndpoint.  # noqa: E501


        :return: The model_id of this ModelEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this ModelEndpoint.


        :param model_id: The model_id of this ModelEndpoint.  # noqa: E501
        :type: str
        """
        if model_id is None:
            raise ValueError("Invalid value for `model_id`, must not be `None`")  # noqa: E501

        self._model_id = model_id

    @property
    def model_job_id(self):
        """Gets the model_job_id of this ModelEndpoint.  # noqa: E501


        :return: The model_job_id of this ModelEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._model_job_id

    @model_job_id.setter
    def model_job_id(self, model_job_id):
        """Sets the model_job_id of this ModelEndpoint.


        :param model_job_id: The model_job_id of this ModelEndpoint.  # noqa: E501
        :type: str
        """
        if model_job_id is None:
            raise ValueError("Invalid value for `model_job_id`, must not be `None`")  # noqa: E501

        self._model_job_id = model_job_id

    @property
    def created_at(self):
        """Gets the created_at of this ModelEndpoint.  # noqa: E501


        :return: The created_at of this ModelEndpoint.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ModelEndpoint.


        :param created_at: The created_at of this ModelEndpoint.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this ModelEndpoint.  # noqa: E501


        :return: The updated_at of this ModelEndpoint.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ModelEndpoint.


        :param updated_at: The updated_at of this ModelEndpoint.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def version(self):
        """Gets the version of this ModelEndpoint.  # noqa: E501


        :return: The version of this ModelEndpoint.  # noqa: E501
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ModelEndpoint.


        :param version: The version of this ModelEndpoint.  # noqa: E501
        :type: float
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModelEndpoint, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelEndpoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from curia.api.swagger_client.api.internal_api import InternalApi
from curia.api.swagger_client.api.platform_api import PlatformApi
# import ApiClient
from curia.api.swagger_client.api_client import ApiClient
from curia.api.swagger_client.configuration import Configuration
# import models into sdk package
from curia.api.swagger_client.models.body import Body
from curia.api.swagger_client.models.code import Code
from curia.api.swagger_client.models.cohort import Cohort
from curia.api.swagger_client.models.cohort_filter import CohortFilter
from curia.api.swagger_client.models.cohort_filter_condition import CohortFilterCondition
from curia.api.swagger_client.models.cohort_window import CohortWindow
from curia.api.swagger_client.models.create_many_code_dto import CreateManyCodeDto
from curia.api.swagger_client.models.create_many_cohort_dto import CreateManyCohortDto
from curia.api.swagger_client.models.create_many_dataset_dto import CreateManyDatasetDto
from curia.api.swagger_client.models.create_many_environment_dto import CreateManyEnvironmentDto
from curia.api.swagger_client.models.create_many_feature_category_dto import CreateManyFeatureCategoryDto
from curia.api.swagger_client.models.create_many_feature_dto import CreateManyFeatureDto
from curia.api.swagger_client.models.create_many_feature_sub_category_dto import CreateManyFeatureSubCategoryDto
from curia.api.swagger_client.models.create_many_model_dataset_dto import CreateManyModelDatasetDto
from curia.api.swagger_client.models.create_many_model_dto import CreateManyModelDto
from curia.api.swagger_client.models.create_many_model_endpoint_dto import CreateManyModelEndpointDto
from curia.api.swagger_client.models.create_many_model_job_dto import CreateManyModelJobDto
from curia.api.swagger_client.models.create_many_organization_dto import CreateManyOrganizationDto
from curia.api.swagger_client.models.create_many_organization_setting_dto import CreateManyOrganizationSettingDto
from curia.api.swagger_client.models.create_many_project_dto import CreateManyProjectDto
from curia.api.swagger_client.models.create_many_project_member_dto import CreateManyProjectMemberDto
from curia.api.swagger_client.models.create_many_user_favorite_dto import CreateManyUserFavoriteDto
from curia.api.swagger_client.models.dataset import Dataset
from curia.api.swagger_client.models.environment import Environment
from curia.api.swagger_client.models.environment_activity import EnvironmentActivity
from curia.api.swagger_client.models.feature import Feature
from curia.api.swagger_client.models.feature_category import FeatureCategory
from curia.api.swagger_client.models.feature_sub_category import FeatureSubCategory
from curia.api.swagger_client.models.feature_table import FeatureTable
from curia.api.swagger_client.models.get_many_code_response_dto import GetManyCodeResponseDto
from curia.api.swagger_client.models.get_many_cohort_response_dto import GetManyCohortResponseDto
from curia.api.swagger_client.models.get_many_dataset_response_dto import GetManyDatasetResponseDto
from curia.api.swagger_client.models.get_many_environment_response_dto import GetManyEnvironmentResponseDto
from curia.api.swagger_client.models.get_many_feature_category_response_dto import GetManyFeatureCategoryResponseDto
from curia.api.swagger_client.models.get_many_feature_response_dto import GetManyFeatureResponseDto
from curia.api.swagger_client.models.get_many_feature_sub_category_response_dto import GetManyFeatureSubCategoryResponseDto
from curia.api.swagger_client.models.get_many_model_dataset_response_dto import GetManyModelDatasetResponseDto
from curia.api.swagger_client.models.get_many_model_endpoint_response_dto import GetManyModelEndpointResponseDto
from curia.api.swagger_client.models.get_many_model_job_event_response_dto import GetManyModelJobEventResponseDto
from curia.api.swagger_client.models.get_many_model_job_response_dto import GetManyModelJobResponseDto
from curia.api.swagger_client.models.get_many_model_job_status_response_dto import GetManyModelJobStatusResponseDto
from curia.api.swagger_client.models.get_many_model_response_dto import GetManyModelResponseDto
from curia.api.swagger_client.models.get_many_organization_response_dto import GetManyOrganizationResponseDto
from curia.api.swagger_client.models.get_many_organization_setting_response_dto import GetManyOrganizationSettingResponseDto
from curia.api.swagger_client.models.get_many_project_member_response_dto import GetManyProjectMemberResponseDto
from curia.api.swagger_client.models.get_many_project_response_dto import GetManyProjectResponseDto
from curia.api.swagger_client.models.get_many_user_favorite_response_dto import GetManyUserFavoriteResponseDto
from curia.api.swagger_client.models.model import Model
from curia.api.swagger_client.models.model_dataset import ModelDataset
from curia.api.swagger_client.models.model_endpoint import ModelEndpoint
from curia.api.swagger_client.models.model_job import ModelJob
from curia.api.swagger_client.models.model_job_event import ModelJobEvent
from curia.api.swagger_client.models.model_job_output_feature import ModelJobOutputFeature
from curia.api.swagger_client.models.model_job_status import ModelJobStatus
from curia.api.swagger_client.models.organization import Organization
from curia.api.swagger_client.models.organization_setting import OrganizationSetting
from curia.api.swagger_client.models.period_definition import PeriodDefinition
from curia.api.swagger_client.models.project import Project
from curia.api.swagger_client.models.project_member import ProjectMember
from curia.api.swagger_client.models.update_user_dto import UpdateUserDto
from curia.api.swagger_client.models.user_favorite import UserFavorite



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FeatureTable(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'table_name': 'str',
        'table_alias': 'str',
        'has_date': 'bool',
        'foreign_table_alias': 'str',
        'foreign_key': 'str',
        'join_where': 'str',
        'self_key': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'version': 'float'
    }

    attribute_map = {
        'id': 'id',
        'table_name': 'tableName',
        'table_alias': 'tableAlias',
        'has_date': 'hasDate',
        'foreign_table_alias': 'foreignTableAlias',
        'foreign_key': 'foreignKey',
        'join_where': 'joinWhere',
        'self_key': 'selfKey',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'version': 'version'
    }

    def __init__(self, id=None, table_name=None, table_alias=None, has_date=None, foreign_table_alias=None, foreign_key=None, join_where=None, self_key=None, created_at=None, updated_at=None, version=None):  # noqa: E501
        """FeatureTable - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._table_name = None
        self._table_alias = None
        self._has_date = None
        self._foreign_table_alias = None
        self._foreign_key = None
        self._join_where = None
        self._self_key = None
        self._created_at = None
        self._updated_at = None
        self._version = None
        self.discriminator = None
        if id is not None:
            self.id = id
        self.table_name = table_name
        self.table_alias = table_alias
        self.has_date = has_date
        self.foreign_table_alias = foreign_table_alias
        self.foreign_key = foreign_key
        if join_where is not None:
            self.join_where = join_where
        self.self_key = self_key
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if version is not None:
            self.version = version

    @property
    def id(self):
        """Gets the id of this FeatureTable.  # noqa: E501


        :return: The id of this FeatureTable.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FeatureTable.


        :param id: The id of this FeatureTable.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def table_name(self):
        """Gets the table_name of this FeatureTable.  # noqa: E501


        :return: The table_name of this FeatureTable.  # noqa: E501
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """Sets the table_name of this FeatureTable.


        :param table_name: The table_name of this FeatureTable.  # noqa: E501
        :type: str
        """
        if table_name is None:
            raise ValueError("Invalid value for `table_name`, must not be `None`")  # noqa: E501

        self._table_name = table_name

    @property
    def table_alias(self):
        """Gets the table_alias of this FeatureTable.  # noqa: E501


        :return: The table_alias of this FeatureTable.  # noqa: E501
        :rtype: str
        """
        return self._table_alias

    @table_alias.setter
    def table_alias(self, table_alias):
        """Sets the table_alias of this FeatureTable.


        :param table_alias: The table_alias of this FeatureTable.  # noqa: E501
        :type: str
        """
        if table_alias is None:
            raise ValueError("Invalid value for `table_alias`, must not be `None`")  # noqa: E501

        self._table_alias = table_alias

    @property
    def has_date(self):
        """Gets the has_date of this FeatureTable.  # noqa: E501


        :return: The has_date of this FeatureTable.  # noqa: E501
        :rtype: bool
        """
        return self._has_date

    @has_date.setter
    def has_date(self, has_date):
        """Sets the has_date of this FeatureTable.


        :param has_date: The has_date of this FeatureTable.  # noqa: E501
        :type: bool
        """
        if has_date is None:
            raise ValueError("Invalid value for `has_date`, must not be `None`")  # noqa: E501

        self._has_date = has_date

    @property
    def foreign_table_alias(self):
        """Gets the foreign_table_alias of this FeatureTable.  # noqa: E501


        :return: The foreign_table_alias of this FeatureTable.  # noqa: E501
        :rtype: str
        """
        return self._foreign_table_alias

    @foreign_table_alias.setter
    def foreign_table_alias(self, foreign_table_alias):
        """Sets the foreign_table_alias of this FeatureTable.


        :param foreign_table_alias: The foreign_table_alias of this FeatureTable.  # noqa: E501
        :type: str
        """
        if foreign_table_alias is None:
            raise ValueError("Invalid value for `foreign_table_alias`, must not be `None`")  # noqa: E501

        self._foreign_table_alias = foreign_table_alias

    @property
    def foreign_key(self):
        """Gets the foreign_key of this FeatureTable.  # noqa: E501


        :return: The foreign_key of this FeatureTable.  # noqa: E501
        :rtype: str
        """
        return self._foreign_key

    @foreign_key.setter
    def foreign_key(self, foreign_key):
        """Sets the foreign_key of this FeatureTable.


        :param foreign_key: The foreign_key of this FeatureTable.  # noqa: E501
        :type: str
        """
        if foreign_key is None:
            raise ValueError("Invalid value for `foreign_key`, must not be `None`")  # noqa: E501

        self._foreign_key = foreign_key

    @property
    def join_where(self):
        """Gets the join_where of this FeatureTable.  # noqa: E501


        :return: The join_where of this FeatureTable.  # noqa: E501
        :rtype: str
        """
        return self._join_where

    @join_where.setter
    def join_where(self, join_where):
        """Sets the join_where of this FeatureTable.


        :param join_where: The join_where of this FeatureTable.  # noqa: E501
        :type: str
        """

        self._join_where = join_where

    @property
    def self_key(self):
        """Gets the self_key of this FeatureTable.  # noqa: E501


        :return: The self_key of this FeatureTable.  # noqa: E501
        :rtype: str
        """
        return self._self_key

    @self_key.setter
    def self_key(self, self_key):
        """Sets the self_key of this FeatureTable.


        :param self_key: The self_key of this FeatureTable.  # noqa: E501
        :type: str
        """
        if self_key is None:
            raise ValueError("Invalid value for `self_key`, must not be `None`")  # noqa: E501

        self._self_key = self_key

    @property
    def created_at(self):
        """Gets the created_at of this FeatureTable.  # noqa: E501


        :return: The created_at of this FeatureTable.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this FeatureTable.


        :param created_at: The created_at of this FeatureTable.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this FeatureTable.  # noqa: E501


        :return: The updated_at of this FeatureTable.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this FeatureTable.


        :param updated_at: The updated_at of this FeatureTable.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def version(self):
        """Gets the version of this FeatureTable.  # noqa: E501


        :return: The version of this FeatureTable.  # noqa: E501
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this FeatureTable.


        :param version: The version of this FeatureTable.  # noqa: E501
        :type: float
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FeatureTable, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeatureTable):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CohortWindow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cohort_logic': 'str',
        'outcome_logic': 'str',
        'intervention_logic': 'str',
        'period_definitions': 'list[PeriodDefinition]',
        'outcome_type': 'str',
        'cohort_filters': 'list[CohortFilter]',
        'outcome_total_cost': 'float',
        'outcome_list_query': 'str',
        'outcome_count_query': 'str',
        'intervention_list_query': 'str',
        'intervention_count_query': 'str',
        'cohort_list_query': 'str',
        'cohort_count_query': 'str',
        'outcome_count': 'float',
        'intervention_count': 'float',
        'cohort_count': 'float'
    }

    attribute_map = {
        'cohort_logic': 'cohortLogic',
        'outcome_logic': 'outcomeLogic',
        'intervention_logic': 'interventionLogic',
        'period_definitions': 'periodDefinitions',
        'outcome_type': 'outcomeType',
        'cohort_filters': 'cohortFilters',
        'outcome_total_cost': 'outcomeTotalCost',
        'outcome_list_query': 'outcomeListQuery',
        'outcome_count_query': 'outcomeCountQuery',
        'intervention_list_query': 'interventionListQuery',
        'intervention_count_query': 'interventionCountQuery',
        'cohort_list_query': 'cohortListQuery',
        'cohort_count_query': 'cohortCountQuery',
        'outcome_count': 'outcomeCount',
        'intervention_count': 'interventionCount',
        'cohort_count': 'cohortCount'
    }

    def __init__(self, cohort_logic=None, outcome_logic=None, intervention_logic=None, period_definitions=None, outcome_type=None, cohort_filters=None, outcome_total_cost=None, outcome_list_query=None, outcome_count_query=None, intervention_list_query=None, intervention_count_query=None, cohort_list_query=None, cohort_count_query=None, outcome_count=None, intervention_count=None, cohort_count=None):  # noqa: E501
        """CohortWindow - a model defined in Swagger"""  # noqa: E501
        self._cohort_logic = None
        self._outcome_logic = None
        self._intervention_logic = None
        self._period_definitions = None
        self._outcome_type = None
        self._cohort_filters = None
        self._outcome_total_cost = None
        self._outcome_list_query = None
        self._outcome_count_query = None
        self._intervention_list_query = None
        self._intervention_count_query = None
        self._cohort_list_query = None
        self._cohort_count_query = None
        self._outcome_count = None
        self._intervention_count = None
        self._cohort_count = None
        self.discriminator = None
        self.cohort_logic = cohort_logic
        self.outcome_logic = outcome_logic
        self.intervention_logic = intervention_logic
        self.period_definitions = period_definitions
        self.outcome_type = outcome_type
        self.cohort_filters = cohort_filters
        self.outcome_total_cost = outcome_total_cost
        self.outcome_list_query = outcome_list_query
        self.outcome_count_query = outcome_count_query
        self.intervention_list_query = intervention_list_query
        self.intervention_count_query = intervention_count_query
        self.cohort_list_query = cohort_list_query
        self.cohort_count_query = cohort_count_query
        self.outcome_count = outcome_count
        self.intervention_count = intervention_count
        self.cohort_count = cohort_count

    @property
    def cohort_logic(self):
        """Gets the cohort_logic of this CohortWindow.  # noqa: E501


        :return: The cohort_logic of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._cohort_logic

    @cohort_logic.setter
    def cohort_logic(self, cohort_logic):
        """Sets the cohort_logic of this CohortWindow.


        :param cohort_logic: The cohort_logic of this CohortWindow.  # noqa: E501
        :type: str
        """
        if cohort_logic is None:
            raise ValueError("Invalid value for `cohort_logic`, must not be `None`")  # noqa: E501

        self._cohort_logic = cohort_logic

    @property
    def outcome_logic(self):
        """Gets the outcome_logic of this CohortWindow.  # noqa: E501


        :return: The outcome_logic of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._outcome_logic

    @outcome_logic.setter
    def outcome_logic(self, outcome_logic):
        """Sets the outcome_logic of this CohortWindow.


        :param outcome_logic: The outcome_logic of this CohortWindow.  # noqa: E501
        :type: str
        """
        if outcome_logic is None:
            raise ValueError("Invalid value for `outcome_logic`, must not be `None`")  # noqa: E501

        self._outcome_logic = outcome_logic

    @property
    def intervention_logic(self):
        """Gets the intervention_logic of this CohortWindow.  # noqa: E501


        :return: The intervention_logic of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._intervention_logic

    @intervention_logic.setter
    def intervention_logic(self, intervention_logic):
        """Sets the intervention_logic of this CohortWindow.


        :param intervention_logic: The intervention_logic of this CohortWindow.  # noqa: E501
        :type: str
        """
        if intervention_logic is None:
            raise ValueError("Invalid value for `intervention_logic`, must not be `None`")  # noqa: E501

        self._intervention_logic = intervention_logic

    @property
    def period_definitions(self):
        """Gets the period_definitions of this CohortWindow.  # noqa: E501


        :return: The period_definitions of this CohortWindow.  # noqa: E501
        :rtype: list[PeriodDefinition]
        """
        return self._period_definitions

    @period_definitions.setter
    def period_definitions(self, period_definitions):
        """Sets the period_definitions of this CohortWindow.


        :param period_definitions: The period_definitions of this CohortWindow.  # noqa: E501
        :type: list[PeriodDefinition]
        """
        if period_definitions is None:
            raise ValueError("Invalid value for `period_definitions`, must not be `None`")  # noqa: E501

        self._period_definitions = period_definitions

    @property
    def outcome_type(self):
        """Gets the outcome_type of this CohortWindow.  # noqa: E501


        :return: The outcome_type of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._outcome_type

    @outcome_type.setter
    def outcome_type(self, outcome_type):
        """Sets the outcome_type of this CohortWindow.


        :param outcome_type: The outcome_type of this CohortWindow.  # noqa: E501
        :type: str
        """
        if outcome_type is None:
            raise ValueError("Invalid value for `outcome_type`, must not be `None`")  # noqa: E501

        self._outcome_type = outcome_type

    @property
    def cohort_filters(self):
        """Gets the cohort_filters of this CohortWindow.  # noqa: E501


        :return: The cohort_filters of this CohortWindow.  # noqa: E501
        :rtype: list[CohortFilter]
        """
        return self._cohort_filters

    @cohort_filters.setter
    def cohort_filters(self, cohort_filters):
        """Sets the cohort_filters of this CohortWindow.


        :param cohort_filters: The cohort_filters of this CohortWindow.  # noqa: E501
        :type: list[CohortFilter]
        """
        if cohort_filters is None:
            raise ValueError("Invalid value for `cohort_filters`, must not be `None`")  # noqa: E501

        self._cohort_filters = cohort_filters

    @property
    def outcome_total_cost(self):
        """Gets the outcome_total_cost of this CohortWindow.  # noqa: E501


        :return: The outcome_total_cost of this CohortWindow.  # noqa: E501
        :rtype: float
        """
        return self._outcome_total_cost

    @outcome_total_cost.setter
    def outcome_total_cost(self, outcome_total_cost):
        """Sets the outcome_total_cost of this CohortWindow.


        :param outcome_total_cost: The outcome_total_cost of this CohortWindow.  # noqa: E501
        :type: float
        """
        if outcome_total_cost is None:
            raise ValueError("Invalid value for `outcome_total_cost`, must not be `None`")  # noqa: E501

        self._outcome_total_cost = outcome_total_cost

    @property
    def outcome_list_query(self):
        """Gets the outcome_list_query of this CohortWindow.  # noqa: E501


        :return: The outcome_list_query of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._outcome_list_query

    @outcome_list_query.setter
    def outcome_list_query(self, outcome_list_query):
        """Sets the outcome_list_query of this CohortWindow.


        :param outcome_list_query: The outcome_list_query of this CohortWindow.  # noqa: E501
        :type: str
        """
        if outcome_list_query is None:
            raise ValueError("Invalid value for `outcome_list_query`, must not be `None`")  # noqa: E501

        self._outcome_list_query = outcome_list_query

    @property
    def outcome_count_query(self):
        """Gets the outcome_count_query of this CohortWindow.  # noqa: E501


        :return: The outcome_count_query of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._outcome_count_query

    @outcome_count_query.setter
    def outcome_count_query(self, outcome_count_query):
        """Sets the outcome_count_query of this CohortWindow.


        :param outcome_count_query: The outcome_count_query of this CohortWindow.  # noqa: E501
        :type: str
        """
        if outcome_count_query is None:
            raise ValueError("Invalid value for `outcome_count_query`, must not be `None`")  # noqa: E501

        self._outcome_count_query = outcome_count_query

    @property
    def intervention_list_query(self):
        """Gets the intervention_list_query of this CohortWindow.  # noqa: E501


        :return: The intervention_list_query of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._intervention_list_query

    @intervention_list_query.setter
    def intervention_list_query(self, intervention_list_query):
        """Sets the intervention_list_query of this CohortWindow.


        :param intervention_list_query: The intervention_list_query of this CohortWindow.  # noqa: E501
        :type: str
        """
        if intervention_list_query is None:
            raise ValueError("Invalid value for `intervention_list_query`, must not be `None`")  # noqa: E501

        self._intervention_list_query = intervention_list_query

    @property
    def intervention_count_query(self):
        """Gets the intervention_count_query of this CohortWindow.  # noqa: E501


        :return: The intervention_count_query of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._intervention_count_query

    @intervention_count_query.setter
    def intervention_count_query(self, intervention_count_query):
        """Sets the intervention_count_query of this CohortWindow.


        :param intervention_count_query: The intervention_count_query of this CohortWindow.  # noqa: E501
        :type: str
        """
        if intervention_count_query is None:
            raise ValueError("Invalid value for `intervention_count_query`, must not be `None`")  # noqa: E501

        self._intervention_count_query = intervention_count_query

    @property
    def cohort_list_query(self):
        """Gets the cohort_list_query of this CohortWindow.  # noqa: E501


        :return: The cohort_list_query of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._cohort_list_query

    @cohort_list_query.setter
    def cohort_list_query(self, cohort_list_query):
        """Sets the cohort_list_query of this CohortWindow.


        :param cohort_list_query: The cohort_list_query of this CohortWindow.  # noqa: E501
        :type: str
        """
        if cohort_list_query is None:
            raise ValueError("Invalid value for `cohort_list_query`, must not be `None`")  # noqa: E501

        self._cohort_list_query = cohort_list_query

    @property
    def cohort_count_query(self):
        """Gets the cohort_count_query of this CohortWindow.  # noqa: E501


        :return: The cohort_count_query of this CohortWindow.  # noqa: E501
        :rtype: str
        """
        return self._cohort_count_query

    @cohort_count_query.setter
    def cohort_count_query(self, cohort_count_query):
        """Sets the cohort_count_query of this CohortWindow.


        :param cohort_count_query: The cohort_count_query of this CohortWindow.  # noqa: E501
        :type: str
        """
        if cohort_count_query is None:
            raise ValueError("Invalid value for `cohort_count_query`, must not be `None`")  # noqa: E501

        self._cohort_count_query = cohort_count_query

    @property
    def outcome_count(self):
        """Gets the outcome_count of this CohortWindow.  # noqa: E501


        :return: The outcome_count of this CohortWindow.  # noqa: E501
        :rtype: float
        """
        return self._outcome_count

    @outcome_count.setter
    def outcome_count(self, outcome_count):
        """Sets the outcome_count of this CohortWindow.


        :param outcome_count: The outcome_count of this CohortWindow.  # noqa: E501
        :type: float
        """
        if outcome_count is None:
            raise ValueError("Invalid value for `outcome_count`, must not be `None`")  # noqa: E501

        self._outcome_count = outcome_count

    @property
    def intervention_count(self):
        """Gets the intervention_count of this CohortWindow.  # noqa: E501


        :return: The intervention_count of this CohortWindow.  # noqa: E501
        :rtype: float
        """
        return self._intervention_count

    @intervention_count.setter
    def intervention_count(self, intervention_count):
        """Sets the intervention_count of this CohortWindow.


        :param intervention_count: The intervention_count of this CohortWindow.  # noqa: E501
        :type: float
        """
        if intervention_count is None:
            raise ValueError("Invalid value for `intervention_count`, must not be `None`")  # noqa: E501

        self._intervention_count = intervention_count

    @property
    def cohort_count(self):
        """Gets the cohort_count of this CohortWindow.  # noqa: E501


        :return: The cohort_count of this CohortWindow.  # noqa: E501
        :rtype: float
        """
        return self._cohort_count

    @cohort_count.setter
    def cohort_count(self, cohort_count):
        """Sets the cohort_count of this CohortWindow.


        :param cohort_count: The cohort_count of this CohortWindow.  # noqa: E501
        :type: float
        """
        if cohort_count is None:
            raise ValueError("Invalid value for `cohort_count`, must not be `None`")  # noqa: E501

        self._cohort_count = cohort_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CohortWindow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CohortWindow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import logging

from logzero import setup_logger

import curia.api.swagger_client as swagger_client
from curia.api.swagger_client import configuration

DEFAULT_LOG_LEVEL = logging.INFO


class Session():
    """Creates a Curia authentication session"""

    def __init__(self, api_token: str = None, host: str = None, debug: bool = False):
        """

        Parameters
        ----------
        api_token: str :
        host: str :
        debug: bool :
        """
        self.api_token = api_token
        self.debug = debug
        self.logger = setup_logger(name='curia', level=DEFAULT_LOG_LEVEL)
        self.api_client = swagger_client

        if debug:
            self.logger.setLevel(logging.DEBUG)

        api_config = configuration.Configuration()
        api_config.debug = self.debug
        api_config.api_key['Api-Key'] = self.api_token
        if host:
            api_config.host = host

        self.api_instance = swagger_client.PlatformApi(swagger_client.ApiClient(api_config))



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import curia.api.swagger_client
from curia.api.swagger_client.models.model_job_event import ModelJobEvent  # noqa: E501
from curia.api.swagger_client.rest import ApiException


class TestModelJobEvent(unittest.TestCase):
    """ModelJobEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testModelJobEvent(self):
        """Test ModelJobEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.model_job_event.ModelJobEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
